@@ -7,20 +7,21 @@ from github import Github, GithubException
 
 class Py3status:
     cache_timeout = 300
-    format = ": {notifications}"
-    gh_token = "pass in your token"
+    format = " {notifications}"
+    gh_token = "put your token here"
 
     def _get_notifications(self):
         try:
             return Github(self.gh_token).get_user().get_notifications().totalCount
 
         except GithubException as github_exception:
-            return f"error {github_exception}"
+            print(f"error {github_exception}")
+            raise
 
     def github_notifications(self):
         notifications = self._get_notifications()
         full_text = self.py3.safe_format(self.format, {"notifications": notifications})
-        if notifications > 0:
+        if notifications and notifications > 0:
             color = self.py3.COLOR_BAD
         else:
             color = self.py3.COLOR_GOOD
